@@ -47,12 +47,7 @@ impl<T: ShaderDescriptor<TEXTURES>, const TEXTURES: usize> Shader<T, TEXTURES> {
         }
     }
 
-    fn bind(
-        &self,
-        uniform: &Uniform<T::VertexUniformType>,
-        textures: [&Texture; TEXTURES],
-        buffer: &Buffer<T::VertexDescriptor>,
-    ) {
+    fn bind(&self, uniform: &Uniform<T::VertexUniformType>, textures: [&Texture; TEXTURES]) {
         let gl = ctx().graphics().gl();
         gl.use_program(Some(self.program));
         uniform.bind(0);
@@ -60,7 +55,6 @@ impl<T: ShaderDescriptor<TEXTURES>, const TEXTURES: usize> Shader<T, TEXTURES> {
             textures[i].bind(i as u32);
             gl.uniform_1_i32(Some(&self.texture_locations[i]), i as i32);
         }
-        buffer.bind();
     }
 
     /// Performs an instanced draw to the screen.
@@ -69,20 +63,23 @@ impl<T: ShaderDescriptor<TEXTURES>, const TEXTURES: usize> Shader<T, TEXTURES> {
     /// * `mode` - Specifies what kind of primitives to render.
     /// * `uniform` - The uniform to use for the shader invocation.
     /// * `textures` - The set of textures to use in the fragment shader.
-    /// * `buffer` - The buffer of vertices to draw.
+    /// * `buffers` - The set of buffers of vertices to draw, reusing the uniform and textures for
+    /// each buffer draw.
     /// * `count` - Specifies the number of instances to be rendered.
     pub fn draw_instanced(
         &self,
         mode: DrawMode,
         uniform: &Uniform<T::VertexUniformType>,
         textures: [&Texture; TEXTURES],
-        buffer: &Buffer<T::VertexDescriptor>,
+        buffers: &[&Buffer<T::VertexDescriptor>],
         count: i32,
     ) {
-        if buffer.len() > 0 {
-            self.bind(uniform, textures, buffer);
-            let gl = ctx().graphics().gl();
-            gl.draw_arrays_instanced(mode, 0, count, buffer.len() as i32);
+        self.bind(uniform, textures);
+        for buffer in buffers {
+            if buffer.len() > 0 {
+                buffer.bind();
+                ctx().graphics().gl().draw_arrays_instanced(mode, 0, count, buffer.len() as i32);
+            }
         }
     }
 
@@ -92,18 +89,21 @@ impl<T: ShaderDescriptor<TEXTURES>, const TEXTURES: usize> Shader<T, TEXTURES> {
     /// * `mode` - Specifies what kind of primitives to render.
     /// * `uniform` - The uniform to use for the shader invocation.
     /// * `textures` - The set of textures to use in the fragment shader.
-    /// * `buffer` - The buffer of vertices to draw.
+    /// * `buffers` - The set of buffers of vertices to draw, reusing the uniform and textures for
+    /// each buffer draw.
     pub fn draw(
         &self,
         mode: DrawMode,
         uniform: &Uniform<T::VertexUniformType>,
         textures: [&Texture; TEXTURES],
-        buffer: &Buffer<T::VertexDescriptor>,
+        buffers: &[&Buffer<T::VertexDescriptor>],
     ) {
-        if buffer.len() > 0 {
-            self.bind(uniform, textures, buffer);
-            let gl = ctx().graphics().gl();
-            gl.draw_arrays(mode, 0, buffer.len() as i32);
+        self.bind(uniform, textures);
+        for buffer in buffers {
+            if buffer.len() > 0 {
+                buffer.bind();
+                ctx().graphics().gl().draw_arrays(mode, 0, buffer.len() as i32);
+            }
         }
     }
 }
